@@ -2,6 +2,8 @@ import xml.dom.minidom
 import yaml
 import pathlib
 
+ADDONS_CONFIG_FILE = 'addons.yml'
+
 config = {}
 
 attrib = {
@@ -48,7 +50,9 @@ class AddonUi:
         root.appendChild(n_addonUI)
 
         # add Office Menu Bar
-        n_addonUI.appendChild(self.build_menu_bar())
+        mb = self.build_menu_bar()
+        if mb:
+            n_addonUI.appendChild(mb)
 
         # different strategy as we build tb & images in the same time
         self.build_toolbar(n_addonUI)
@@ -59,27 +63,29 @@ class AddonUi:
         node = get_node(self.doc, at_name(config['lib']), AT_REPLACE)
         mb.appendChild(node)
 
-        node.appendChild(get_prop(self.doc, 'Title', 'RDT'))
+        node.appendChild(get_prop(self.doc, 'Title', config['menu_name']))
         node.appendChild(get_prop(self.doc, 'Target', '_self'))
 
         # Menu bar configuration
         menu_bar_conf = self.conf.get('OfficeMenuBar')
+        
+        if menu_bar_conf:
 
-        submenu = node.appendChild(self.get_new_submenu_node())
-        for i, (k, v) in enumerate(menu_bar_conf.items(), 1):
-            if 'submenu' in v.keys():
-                # This is a new submenu
-                node.appendChild(self.create_subentries(v, i))
-            else:
-                # This is new section entry
-                m = MenuEntry(self.doc, k, v['title'], i)
-                submenu.appendChild(m.root)
+            submenu = node.appendChild(self.get_new_submenu_node())
+            for i, (k, v) in enumerate(menu_bar_conf.items(), 1):
+                if 'submenu' in v.keys():
+                    # This is a new submenu
+                    node.appendChild(self.create_subentries(v, i))
+                else:
+                    # This is new section entry
+                    m = MenuEntry(self.doc, k, v['title'], i)
+                    submenu.appendChild(m.root)
 
-        return mb
+            return mb
 
     def build_toolbar(self, root):
         tb = get_node(self.doc, at_name('OfficeToolBar'),)
-        tb_node = get_node(self.doc, at_name("rdt_tools.OfficeToolBar"), AT_REPLACE)
+        tb_node = get_node(self.doc, at_name(f"{config['extension_name']}.OfficeToolBar"), AT_REPLACE)
         tb.appendChild(tb_node)
         root.appendChild(tb)
 
@@ -112,8 +118,13 @@ class AddonUi:
         return nn
 
     def read_addon_yaml(self):
-        cp = pathlib.Path.cwd()
-        with open((cp / config['addons_conf']), 'r') as f:
+        cp = (pathlib.Path.cwd() / ADDONS_CONFIG_FILE)
+        try:
+            assert(cp.exists())
+        except AssertionError:
+            raise(FileNotFoundError(f"<{ADDONS_CONFIG_FILE}> is missing. "
+                                    f"It must be found in root directory."))
+        with open(cp, 'r') as f:
             self.conf = yaml.safe_load(f)
 
 
